bayespy.inference.vmp.nodes.gamma.GammaDistribution.random
==========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. automethod:: GammaDistribution.random